#
# PySNMP MIB module DISMAN-EVENT-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/DISMAN-EVENT-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:07:55 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ValueSizeConstraint, SingleValueConstraint, ValueRangeConstraint, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ValueSizeConstraint", "SingleValueConstraint", "ValueRangeConstraint", "ConstraintsUnion")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( SnmpTagValue, ) = mibBuilder.importSymbols("SNMP-TARGET-MIB", "SnmpTagValue")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( sysUpTime, ) = mibBuilder.importSymbols("SNMPv2-MIB", "sysUpTime")
( Counter32, Counter64, Integer32, Unsigned32, Gauge32, TimeTicks, MibIdentifier, iso, IpAddress, mib_2, zeroDotZero, ModuleIdentity, ObjectIdentity, NotificationType, MibScalar, MibTable, MibTableRow, MibTableColumn, Bits, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter32", "Counter64", "Integer32", "Unsigned32", "Gauge32", "TimeTicks", "MibIdentifier", "iso", "IpAddress", "mib-2", "zeroDotZero", "ModuleIdentity", "ObjectIdentity", "NotificationType", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Bits")
( RowStatus, TruthValue, StorageType, DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowStatus", "TruthValue", "StorageType", "DisplayString", "TextualConvention")
dismanEventMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 88)).setRevisions(("2001-11-14 00:00", "2000-10-16 00:00",))
if mibBuilder.loadTexts: dismanEventMIB.setLastUpdated('200111140000Z')
if mibBuilder.loadTexts: dismanEventMIB.setOrganization('IETF Distributed Management Working Group')
if mibBuilder.loadTexts: dismanEventMIB.setContactInfo('Ramanathan Kavasseri\n                  Cisco Systems, Inc.\n                  170 West Tasman Drive,\n                  San Jose CA 95134-1706.\n                  Phone: +1 408 526 4527\n                  Email: ramk@cisco.com')
if mibBuilder.loadTexts: dismanEventMIB.setDescription('The MIB module for defining event triggers and actions\n     for network management purposes.')
dismanEventMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 88, 1))
mteResource = MibIdentifier((1, 3, 6, 1, 2, 1, 88, 1, 1))
mteTrigger = MibIdentifier((1, 3, 6, 1, 2, 1, 88, 1, 2))
mteObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 88, 1, 3))
mteEvent = MibIdentifier((1, 3, 6, 1, 2, 1, 88, 1, 4))
class FailureReason(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(-1, -2, -3, -4, -5, -6, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,))
    namedValues = NamedValues(("localResourceLack", -1), ("badDestination", -2), ("destinationUnreachable", -3), ("noResponse", -4), ("badType", -5), ("sampleOverrun", -6), ("noError", 0), ("tooBig", 1), ("noSuchName", 2), ("badValue", 3), ("readOnly", 4), ("genErr", 5), ("noAccess", 6), ("wrongType", 7), ("wrongLength", 8), ("wrongEncoding", 9), ("wrongValue", 10), ("noCreation", 11), ("inconsistentValue", 12), ("resourceUnavailable", 13), ("commitFailed", 14), ("undoFailed", 15), ("authorizationError", 16), ("notWritable", 17), ("inconsistentName", 18),)

mteResourceSampleMinimum = MibScalar((1, 3, 6, 1, 2, 1, 88, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteResourceSampleMinimum.setDescription("The minimum mteTriggerFrequency this system will\n        accept.  A system may use the larger values of this minimum to\n        lessen the impact of constant sampling.  For larger\n        sampling intervals the system samples less often and\n        suffers less overhead.  This object provides a way to enforce\n        such lower overhead for all triggers created after it is\n        set.\n\n        Unless explicitly resource limited, a system's value for\n        this object SHOULD be 1, allowing as small as a 1 second\n        interval for ongoing trigger sampling.\n\n        Changing this value will not invalidate an existing setting\n        of mteTriggerFrequency.")
mteResourceSampleInstanceMaximum = MibScalar((1, 3, 6, 1, 2, 1, 88, 1, 1, 2), Unsigned32()).setUnits('instances').setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteResourceSampleInstanceMaximum.setDescription("The maximum number of instance entries this system will\n        support for sampling.\n\n        These are the entries that maintain state, one for each\n        instance of each sampled object as selected by\n        mteTriggerValueID.  Note that wildcarded objects result\n        in multiple instances of this state.\n\n        A value of 0 indicates no preset limit, that is, the limit\n        is dynamic based on system operation and resources.\n\n        Unless explicitly resource limited, a system's value for\n        this object SHOULD be 0.\n\n        Changing this value will not eliminate or inhibit existing\n        sample state but could prevent allocation of additional state\n        information.")
mteResourceSampleInstances = MibScalar((1, 3, 6, 1, 2, 1, 88, 1, 1, 3), Gauge32()).setUnits('instances').setMaxAccess("readonly")
if mibBuilder.loadTexts: mteResourceSampleInstances.setDescription('The number of currently active instance entries as\n        defined for mteResourceSampleInstanceMaximum.')
mteResourceSampleInstancesHigh = MibScalar((1, 3, 6, 1, 2, 1, 88, 1, 1, 4), Gauge32()).setUnits('instances').setMaxAccess("readonly")
if mibBuilder.loadTexts: mteResourceSampleInstancesHigh.setDescription('The highest value of mteResourceSampleInstances that has\n        occurred since initialization of the management system.')
mteResourceSampleInstanceLacks = MibScalar((1, 3, 6, 1, 2, 1, 88, 1, 1, 5), Counter32()).setUnits('instances').setMaxAccess("readonly")
if mibBuilder.loadTexts: mteResourceSampleInstanceLacks.setDescription('The number of times this system could not take a new sample\n        because that allocation would have exceeded the limit set by\n        mteResourceSampleInstanceMaximum.')
mteTriggerFailures = MibScalar((1, 3, 6, 1, 2, 1, 88, 1, 2, 1), Counter32()).setUnits('failures').setMaxAccess("readonly")
if mibBuilder.loadTexts: mteTriggerFailures.setDescription('The number of times an attempt to check for a trigger\n        condition has failed.  This counts individually for each\n        attempt in a group of targets or each attempt for a\n        wildcarded object.')
mteTriggerTable = MibTable((1, 3, 6, 1, 2, 1, 88, 1, 2, 2), )
if mibBuilder.loadTexts: mteTriggerTable.setDescription('A table of management event trigger information.')
mteTriggerEntry = MibTableRow((1, 3, 6, 1, 2, 1, 88, 1, 2, 2, 1), ).setIndexNames((0, "DISMAN-EVENT-MIB", "mteOwner"), (1, "DISMAN-EVENT-MIB", "mteTriggerName"))
if mibBuilder.loadTexts: mteTriggerEntry.setDescription('Information about a single trigger.  Applications create and\n        delete entries using mteTriggerEntryStatus.')
mteOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 2, 1, 1), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)))
if mibBuilder.loadTexts: mteOwner.setDescription('The owner of this entry. The exact semantics of this\n        string are subject to the security policy defined by the\n        security administrator.')
mteTriggerName = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 2, 1, 2), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(1,32)))
if mibBuilder.loadTexts: mteTriggerName.setDescription('A locally-unique, administratively assigned name for the\n        trigger within the scope of mteOwner.')
mteTriggerComment = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 2, 1, 3), SnmpAdminString().clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteTriggerComment.setDescription("A description of the trigger's function and use.")
mteTriggerTest = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 2, 1, 4), Bits().clone(namedValues=NamedValues(("existence", 0), ("boolean", 1), ("threshold", 2),)).clone(namedValues=NamedValues(("boolean", 1),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteTriggerTest.setDescription("The type of trigger test to perform.  For 'boolean' and\n        'threshold'  tests, the object at mteTriggerValueID MUST\n        evaluate to an integer, that is, anything that ends up encoded\n        for transmission (that is, in BER, not ASN.1) as an integer.\n\n        For 'existence', the specific test is as selected by\n        mteTriggerExistenceTest.  When an object appears, vanishes\n        or changes value, the trigger fires. If the object's\n        appearance caused the trigger firing, the object MUST\n        vanish before the trigger can be fired again for it, and\n        vice versa. If the trigger fired due to a change in the\n        object's value, it will be fired again on every successive\n        value change for that object.\n\n        For 'boolean', the specific test is as selected by\n        mteTriggerBooleanTest.  If the test result is true the trigger\n        fires.  The trigger will not fire again until the value has\n        become false and come back to true.\n\n        For 'threshold' the test works as described below for\n        mteTriggerThresholdStartup, mteTriggerThresholdRising, and\n        mteTriggerThresholdFalling.\n\n        Note that combining 'boolean' and 'threshold' tests on the\n        same object may be somewhat redundant.")
mteTriggerSampleType = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 2, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("absoluteValue", 1), ("deltaValue", 2),)).clone('absoluteValue')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteTriggerSampleType.setDescription("The type of sampling to perform.\n\n        An 'absoluteValue' sample requires only a single sample to be\n        meaningful, and is exactly the value of the object at\n        mteTriggerValueID at the sample time.\n\n        A 'deltaValue' requires two samples to be meaningful and is\n        thus not available for testing until the second and subsequent\n        samples after the object at mteTriggerValueID is first found\n        to exist.  It is the difference between the two samples.  For\n        unsigned values it is always positive, based on unsigned\n        arithmetic.  For signed values it can be positive or negative.\n\n        For SNMP counters to be meaningful they should be sampled as a\n        'deltaValue'.\n\n        For 'deltaValue' mteTriggerDeltaTable contains further\n        parameters.\n\n        If only 'existence' is set in mteTriggerTest this object has\n        no meaning.")
mteTriggerValueID = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 2, 1, 6), ObjectIdentifier().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteTriggerValueID.setDescription("The object identifier of the MIB object to sample to see\n        if the trigger should fire.\n\n        This may be wildcarded by truncating all or part of the\n        instance portion, in which case the value is obtained\n        as if with a GetNext function, checking multiple values\n        if they exist.  If such wildcarding is applied,\n        mteTriggerValueIDWildcard must be 'true' and if not it must\n        be 'false'.\n\n        Bad object identifiers or a mismatch between truncating the\n        identifier and the value of mteTriggerValueIDWildcard result\n        in operation as one would expect when providing the wrong\n        identifier to a Get or GetNext operation.  The Get will fail\n        or get the wrong object.  The GetNext will indeed get whatever\n        is next, proceeding until it runs past the initial part of the\n        identifier and perhaps many unintended objects for confusing\n        results.  If the value syntax of those objects is not usable,\n        that results in a 'badType' error that terminates the scan.\n\n        Each instance that fills the wildcard is independent of any\n        additional instances, that is, wildcarded objects operate\n        as if there were a separate table entry for each instance\n        that fills the wildcard without having to actually predict\n        all possible instances ahead of time.")
mteTriggerValueIDWildcard = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 2, 1, 7), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteTriggerValueIDWildcard.setDescription("Control for whether mteTriggerValueID is to be treated as\n        fully-specified or wildcarded, with 'true' indicating wildcard.")
mteTriggerTargetTag = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 2, 1, 8), SnmpTagValue().clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteTriggerTargetTag.setDescription("The tag for the target(s) from which to obtain the condition\n        for a trigger check.\n\n        A length of 0 indicates the local system.  In this case,\n        access to the objects indicated by mteTriggerValueID is under\n        the security credentials of the requester that set\n        mteTriggerEntryStatus to 'active'.  Those credentials are the\n        input parameters for isAccessAllowed from the Architecture for\n        Describing SNMP Management Frameworks.\n\n        Otherwise access rights are checked according to the security\n        parameters resulting from the tag.")
mteTriggerContextName = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 2, 1, 9), SnmpAdminString().clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteTriggerContextName.setDescription("The management context from which to obtain mteTriggerValueID.\n\n        This may be wildcarded by leaving characters off the end.  For\n        example use 'Repeater' to wildcard to 'Repeater1',\n        'Repeater2', 'Repeater-999.87b', and so on.  To indicate such\n        wildcarding is intended, mteTriggerContextNameWildcard must\n        be 'true'.\n\n        Each instance that fills the wildcard is independent of any\n        additional instances, that is, wildcarded objects operate\n        as if there were a separate table entry for each instance\n        that fills the wildcard without having to actually predict\n        all possible instances ahead of time.\n\n        Operation of this feature assumes that the local system has a\n        list of available contexts against which to apply the\n        wildcard.  If the objects are being read from the local\n        system, this is clearly the system's own list of contexts.\n        For a remote system a local version of such a list is not\n        defined by any current standard and may not be available, so\n        this function MAY not be supported.")
mteTriggerContextNameWildcard = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 2, 1, 10), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteTriggerContextNameWildcard.setDescription("Control for whether mteTriggerContextName is to be treated as\n        fully-specified or wildcarded, with 'true' indicating wildcard.")
mteTriggerFrequency = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 2, 1, 11), Unsigned32().clone(600)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteTriggerFrequency.setDescription("The number of seconds to wait between trigger samples.  To\n        encourage consistency in sampling, the interval is measured\n        from the beginning of one check to the beginning of the next\n        and the timer is restarted immediately when it expires, not\n        when the check completes.\n\n        If the next sample begins before the previous one completed the\n        system may either attempt to make the check or treat this as an\n        error condition with the error 'sampleOverrun'.\n        A frequency of 0 indicates instantaneous recognition of the\n        condition.  This is not possible in many cases, but may\n        be supported in cases where it makes sense and the system is\n        able to do so.  This feature allows the MIB to be used in\n        implementations where such interrupt-driven behavior is\n        possible and is not likely to be supported for all MIB objects\n        even then since such sampling generally has to be tightly\n        integrated into low-level code.\n\n        Systems that can support this SHOULD document those cases\n        where it can be used.  In cases where it can not, setting this\n        object to 0 should be disallowed.")
mteTriggerObjectsOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 2, 1, 12), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteTriggerObjectsOwner.setDescription('To go with mteTriggerObjects, the mteOwner of a group of\n        objects from mteObjectsTable.')
mteTriggerObjects = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 2, 1, 13), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteTriggerObjects.setDescription('The mteObjectsName of a group of objects from\n        mteObjectsTable.  These objects are to be added to any\n        Notification resulting from the firing of this trigger.\n\n        A list of objects may also be added based on the event or on\n        the value of mteTriggerTest.\n\n        A length of 0 indicates no additional objects.')
mteTriggerEnabled = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 2, 1, 14), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteTriggerEnabled.setDescription("A control to allow a trigger to be configured but not used.\n        When the value is 'false' the trigger is not sampled.\n\n        Whenever the value goes from 'false' to 'true', the trigger\n        is treated as being initialized.  That is, no history is kept\n        of any trigger sample values from previous times when this\n        control may have been enabled.\n\n        If this object is set to 'true' when its value\n        is already 'true', the operation has no effect;\n        that is, the trigger is not re-initialized, and\n        there is no error.")
mteTriggerEntryStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 2, 1, 15), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteTriggerEntryStatus.setDescription('The control that allows creation and deletion of entries.\n        Once made active an entry may not be modified except to\n        modify the value of mteTriggerEnabled or to delete the\n        entry.')
mteTriggerEntryStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 2, 1, 16), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteTriggerEntryStorageType.setDescription("The storage type for this conceptual row.\n                 Conceptual rows having the value 'permanent' need not\n                 allow write-access to any columnar objects in the row,\n                 except for mteTriggerEnabled.\n                ")
mteTriggerDeltaTable = MibTable((1, 3, 6, 1, 2, 1, 88, 1, 2, 3), )
if mibBuilder.loadTexts: mteTriggerDeltaTable.setDescription('A table of management event trigger information for delta\n        sampling.')
mteTriggerDeltaEntry = MibTableRow((1, 3, 6, 1, 2, 1, 88, 1, 2, 3, 1), ).setIndexNames((0, "DISMAN-EVENT-MIB", "mteOwner"), (1, "DISMAN-EVENT-MIB", "mteTriggerName"))
if mibBuilder.loadTexts: mteTriggerDeltaEntry.setDescription("Information about a single trigger's delta sampling.  Entries\n        automatically exist in this this table for each mteTriggerEntry\n        that has mteTriggerSampleType set to 'deltaValue'.")
sysUpTimeInstance = MibIdentifier((1, 3, 6, 1, 2, 1, 1, 3, 0))
mteTriggerDeltaDiscontinuityID = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 3, 1, 1), ObjectIdentifier().clone((1, 3, 6, 1, 2, 1, 1, 3, 0))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerDeltaDiscontinuityID.setDescription("The OBJECT IDENTIFIER (OID) of a TimeTicks, TimeStamp, or\n        DateAndTime object that indicates a discontinuity in the value\n        at mteTriggerValueID.\n\n        The OID may be for a leaf object (e.g. sysUpTime.0) or may\n        be wildcarded to match mteTriggerValueID.\n\n        This object supports normal checking for a discontinuity in a\n        counter.  Note that if this object does not point to sysUpTime\n        discontinuity checking MUST still check sysUpTime for an overall\n        discontinuity.\n\n        If the object identified is not accessible the sample attempt\n        is in error, with the error code as from an SNMP request.\n        Bad object identifiers or a mismatch between truncating the\n        identifier and the value of mteDeltaDiscontinuityIDWildcard\n        result in operation as one would expect when providing the\n        wrong identifier to a Get operation.  The Get will fail or get\n        the wrong object.  If the value syntax of those objects is not\n        usable, that results in an error that terminates the sample\n        with a 'badType' error code.")
mteTriggerDeltaDiscontinuityIDWildcard = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 3, 1, 2), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerDeltaDiscontinuityIDWildcard.setDescription("Control for whether mteTriggerDeltaDiscontinuityID is to be\n        treated as fully-specified or wildcarded, with 'true'\n        indicating wildcard. Note that the value of this object will\n        be the same as that of the corresponding instance of\n        mteTriggerValueIDWildcard when the corresponding\n        mteTriggerSampleType is 'deltaValue'.")
mteTriggerDeltaDiscontinuityIDType = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 3, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("timeTicks", 1), ("timeStamp", 2), ("dateAndTime", 3),)).clone('timeTicks')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerDeltaDiscontinuityIDType.setDescription("The value 'timeTicks' indicates the\n        mteTriggerDeltaDiscontinuityID of this row is of syntax\n        TimeTicks.  The value 'timeStamp' indicates syntax TimeStamp.\n        The value 'dateAndTime' indicates syntax DateAndTime.")
mteTriggerExistenceTable = MibTable((1, 3, 6, 1, 2, 1, 88, 1, 2, 4), )
if mibBuilder.loadTexts: mteTriggerExistenceTable.setDescription('A table of management event trigger information for existence\n        triggers.')
mteTriggerExistenceEntry = MibTableRow((1, 3, 6, 1, 2, 1, 88, 1, 2, 4, 1), ).setIndexNames((0, "DISMAN-EVENT-MIB", "mteOwner"), (1, "DISMAN-EVENT-MIB", "mteTriggerName"))
if mibBuilder.loadTexts: mteTriggerExistenceEntry.setDescription("Information about a single existence trigger.  Entries\n        automatically exist in this this table for each mteTriggerEntry\n        that has 'existence' set in mteTriggerTest.")
mteTriggerExistenceTest = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 4, 1, 1), Bits().clone(namedValues=NamedValues(("present", 0), ("absent", 1), ("changed", 2),)).clone(namedValues=NamedValues(("present", 0), ("absent", 1),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerExistenceTest.setDescription("The type of existence test to perform.  The trigger fires\n        when the object at mteTriggerValueID is seen to go from\n        present to absent, from absent to present, or to have it's\n        value changed, depending on which tests are selected:\n\n        present(0) - when this test is selected, the trigger fires\n        when the mteTriggerValueID object goes from absent to present.\n\n        absent(1)  - when this test is selected, the trigger fires\n        when the mteTriggerValueID object goes from present to absent.\n        changed(2) - when this test is selected, the trigger fires\n        the mteTriggerValueID object value changes.\n\n        Once the trigger has fired for either presence or absence it\n        will not fire again for that state until the object has been\n        to the other state. ")
mteTriggerExistenceStartup = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 4, 1, 2), Bits().clone(namedValues=NamedValues(("present", 0), ("absent", 1),)).clone(namedValues=NamedValues(("present", 0), ("absent", 1),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerExistenceStartup.setDescription("Control for whether an event may be triggered when this entry\n        is first set to 'active' and the test specified by\n        mteTriggerExistenceTest is true.  Setting an option causes\n        that trigger to fire when its test is true.")
mteTriggerExistenceObjectsOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 4, 1, 3), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerExistenceObjectsOwner.setDescription('To go with mteTriggerExistenceObjects, the mteOwner of a\n        group of objects from mteObjectsTable.')
mteTriggerExistenceObjects = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 4, 1, 4), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerExistenceObjects.setDescription('The mteObjectsName of a group of objects from\n        mteObjectsTable.  These objects are to be added to any\n        Notification resulting from the firing of this trigger for\n        this test.\n\n        A list of objects may also be added based on the overall\n        trigger, the event or other settings in mteTriggerTest.\n\n        A length of 0 indicates no additional objects.')
mteTriggerExistenceEventOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 4, 1, 5), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerExistenceEventOwner.setDescription('To go with mteTriggerExistenceEvent, the mteOwner of an event\n        entry from the mteEventTable.')
mteTriggerExistenceEvent = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 4, 1, 6), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerExistenceEvent.setDescription("The mteEventName of the event to invoke when mteTriggerType is\n        'existence' and this trigger fires.  A length of 0 indicates no\n        event.")
mteTriggerBooleanTable = MibTable((1, 3, 6, 1, 2, 1, 88, 1, 2, 5), )
if mibBuilder.loadTexts: mteTriggerBooleanTable.setDescription('A table of management event trigger information for boolean\n        triggers.')
mteTriggerBooleanEntry = MibTableRow((1, 3, 6, 1, 2, 1, 88, 1, 2, 5, 1), ).setIndexNames((0, "DISMAN-EVENT-MIB", "mteOwner"), (1, "DISMAN-EVENT-MIB", "mteTriggerName"))
if mibBuilder.loadTexts: mteTriggerBooleanEntry.setDescription("Information about a single boolean trigger.  Entries\n        automatically exist in this this table for each mteTriggerEntry\n        that has 'boolean' set in mteTriggerTest.")
mteTriggerBooleanComparison = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 5, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("unequal", 1), ("equal", 2), ("less", 3), ("lessOrEqual", 4), ("greater", 5), ("greaterOrEqual", 6),)).clone('unequal')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerBooleanComparison.setDescription("The type of boolean comparison to perform.\n\n        The value at mteTriggerValueID is compared to\n        mteTriggerBooleanValue, so for example if\n        mteTriggerBooleanComparison is 'less' the result would be true\n        if the value at mteTriggerValueID is less than the value of\n        mteTriggerBooleanValue.")
mteTriggerBooleanValue = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 5, 1, 2), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerBooleanValue.setDescription('The value to use for the test specified by\n        mteTriggerBooleanTest.')
mteTriggerBooleanStartup = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 5, 1, 3), TruthValue().clone('true')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerBooleanStartup.setDescription("Control for whether an event may be triggered when this entry\n        is first set to 'active' or a new instance of the object at\n        mteTriggerValueID is found and the test specified by\n        mteTriggerBooleanComparison is true.  In that case an event is\n        triggered if mteTriggerBooleanStartup is 'true'.")
mteTriggerBooleanObjectsOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 5, 1, 4), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerBooleanObjectsOwner.setDescription('To go with mteTriggerBooleanObjects, the mteOwner of a group\n        of objects from mteObjectsTable.')
mteTriggerBooleanObjects = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 5, 1, 5), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerBooleanObjects.setDescription('The mteObjectsName of a group of objects from\n        mteObjectsTable.  These objects are to be added to any\n        Notification resulting from the firing of this trigger for\n        this test.\n\n        A list of objects may also be added based on the overall\n        trigger, the event or other settings in mteTriggerTest.\n\n        A length of 0 indicates no additional objects.')
mteTriggerBooleanEventOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 5, 1, 6), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerBooleanEventOwner.setDescription('To go with mteTriggerBooleanEvent, the mteOwner of an event\n        entry from mteEventTable.')
mteTriggerBooleanEvent = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 5, 1, 7), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerBooleanEvent.setDescription("The mteEventName of the event to invoke when mteTriggerType is\n        'boolean' and this trigger fires.  A length of 0 indicates no\n        event.")
mteTriggerThresholdTable = MibTable((1, 3, 6, 1, 2, 1, 88, 1, 2, 6), )
if mibBuilder.loadTexts: mteTriggerThresholdTable.setDescription('A table of management event trigger information for threshold\n        triggers.')
mteTriggerThresholdEntry = MibTableRow((1, 3, 6, 1, 2, 1, 88, 1, 2, 6, 1), ).setIndexNames((0, "DISMAN-EVENT-MIB", "mteOwner"), (1, "DISMAN-EVENT-MIB", "mteTriggerName"))
if mibBuilder.loadTexts: mteTriggerThresholdEntry.setDescription("Information about a single threshold trigger.  Entries\n        automatically exist in this table for each mteTriggerEntry\n        that has 'threshold' set in mteTriggerTest.")
mteTriggerThresholdStartup = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 6, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("rising", 1), ("falling", 2), ("risingOrFalling", 3),)).clone('risingOrFalling')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerThresholdStartup.setDescription("The event that may be triggered when this entry is first\n        set to 'active' and a new instance of the object at\n        mteTriggerValueID is found.  If the first sample after this\n        instance becomes active is greater than or equal to\n        mteTriggerThresholdRising and mteTriggerThresholdStartup is\n        equal to 'rising' or 'risingOrFalling', then one\n        mteTriggerThresholdRisingEvent is triggered for that instance.\n        If the first sample after this entry becomes active is less\n        than or equal to mteTriggerThresholdFalling and\n        mteTriggerThresholdStartup is equal to 'falling' or\n        'risingOrFalling', then one mteTriggerThresholdRisingEvent is\n        triggered for that instance.")
mteTriggerThresholdRising = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 6, 1, 2), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerThresholdRising.setDescription("A threshold value to check against if mteTriggerType is\n        'threshold'.\n\n        When the current sampled value is greater than or equal to\n        this threshold, and the value at the last sampling interval\n        was less than this threshold, one\n        mteTriggerThresholdRisingEvent is triggered.  That event is\n        also triggered if the first sample after this entry becomes\n        active is greater than or equal to this threshold and\n        mteTriggerThresholdStartup is equal to 'rising' or\n        'risingOrFalling'.\n\n        After a rising event is generated, another such event is not\n        triggered until the sampled value falls below this threshold\n        and reaches mteTriggerThresholdFalling.")
mteTriggerThresholdFalling = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 6, 1, 3), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerThresholdFalling.setDescription("A threshold value to check against if mteTriggerType is\n        'threshold'.\n\n        When the current sampled value is less than or equal to this\n        threshold, and the value at the last sampling interval was\n        greater than this threshold, one\n        mteTriggerThresholdFallingEvent is triggered.  That event is\n        also triggered if the first sample after this entry becomes\n        active is less than or equal to this threshold and\n        mteTriggerThresholdStartup is equal to 'falling' or\n        'risingOrFalling'.\n\n        After a falling event is generated, another such event is not\n        triggered until the sampled value rises above this threshold\n        and reaches mteTriggerThresholdRising.")
mteTriggerThresholdDeltaRising = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 6, 1, 4), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerThresholdDeltaRising.setDescription("A threshold value to check against if mteTriggerType is\n        'threshold'.\n\n        When the delta value (difference) between the current sampled\n        value (value(n)) and the previous sampled value (value(n-1))\n        is greater than or equal to this threshold,\n        and the delta value calculated at the last sampling interval\n        (i.e. value(n-1) - value(n-2)) was less than this threshold,\n        one mteTriggerThresholdDeltaRisingEvent is triggered. That event\n        is also triggered if the first delta value calculated after this\n        entry becomes active, i.e. value(2) - value(1), where value(1)\n        is the first sample taken of that instance, is greater than or\n        equal to this threshold.\n\n        After a rising event is generated, another such event is not\n        triggered until the delta value falls below this threshold and\n        reaches mteTriggerThresholdDeltaFalling.")
mteTriggerThresholdDeltaFalling = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 6, 1, 5), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerThresholdDeltaFalling.setDescription("A threshold value to check against if mteTriggerType is\n        'threshold'.\n\n        When the delta value (difference) between the current sampled\n        value (value(n)) and the previous sampled value (value(n-1))\n        is less than or equal to this threshold,\n        and the delta value calculated at the last sampling interval\n        (i.e. value(n-1) - value(n-2)) was greater than this threshold,\n        one mteTriggerThresholdDeltaFallingEvent is triggered. That event\n        is also triggered if the first delta value calculated after this\n        entry becomes active, i.e. value(2) - value(1), where value(1)\n        is the first sample taken of that instance, is less than or\n        equal to this threshold.\n\n        After a falling event is generated, another such event is not\n        triggered until the delta value falls below this threshold and\n        reaches mteTriggerThresholdDeltaRising.")
mteTriggerThresholdObjectsOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 6, 1, 6), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerThresholdObjectsOwner.setDescription('To go with mteTriggerThresholdObjects, the mteOwner of a group\n        of objects from mteObjectsTable.')
mteTriggerThresholdObjects = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 6, 1, 7), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerThresholdObjects.setDescription('The mteObjectsName of a group of objects from\n        mteObjectsTable.  These objects are to be added to any\n        Notification resulting from the firing of this trigger for\n        this test.\n\n        A list of objects may also be added based on the overall\n        trigger, the event or other settings in mteTriggerTest.\n\n        A length of 0 indicates no additional objects.')
mteTriggerThresholdRisingEventOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 6, 1, 8), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerThresholdRisingEventOwner.setDescription('To go with mteTriggerThresholdRisingEvent, the mteOwner of an\n        event entry from mteEventTable.')
mteTriggerThresholdRisingEvent = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 6, 1, 9), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerThresholdRisingEvent.setDescription("The mteEventName of the event to invoke when mteTriggerType is\n        'threshold' and this trigger fires based on\n        mteTriggerThresholdRising.  A length of 0 indicates no event.")
mteTriggerThresholdFallingEventOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 6, 1, 10), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerThresholdFallingEventOwner.setDescription('To go with mteTriggerThresholdFallingEvent, the mteOwner of an\n        event entry from mteEventTable.')
mteTriggerThresholdFallingEvent = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 6, 1, 11), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerThresholdFallingEvent.setDescription("The mteEventName of the event to invoke when mteTriggerType is\n        'threshold' and this trigger fires based on\n        mteTriggerThresholdFalling.  A length of 0 indicates no event.")
mteTriggerThresholdDeltaRisingEventOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 6, 1, 12), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerThresholdDeltaRisingEventOwner.setDescription('To go with mteTriggerThresholdDeltaRisingEvent, the mteOwner\n        of an event entry from mteEventTable.')
mteTriggerThresholdDeltaRisingEvent = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 6, 1, 13), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerThresholdDeltaRisingEvent.setDescription("The mteEventName of the event to invoke when mteTriggerType is\n        'threshold' and this trigger fires based on\n        mteTriggerThresholdDeltaRising. A length of 0 indicates\n        no event.")
mteTriggerThresholdDeltaFallingEventOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 6, 1, 14), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerThresholdDeltaFallingEventOwner.setDescription('To go with mteTriggerThresholdDeltaFallingEvent, the mteOwner\n        of an event entry from mteEventTable.')
mteTriggerThresholdDeltaFallingEvent = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 2, 6, 1, 15), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteTriggerThresholdDeltaFallingEvent.setDescription("The mteEventName of the event to invoke when mteTriggerType is\n        'threshold' and this trigger fires based on\n        mteTriggerThresholdDeltaFalling.  A length of 0 indicates\n        no event.")
mteObjectsTable = MibTable((1, 3, 6, 1, 2, 1, 88, 1, 3, 1), )
if mibBuilder.loadTexts: mteObjectsTable.setDescription('A table of objects that can be added to notifications based\n        on the trigger, trigger test, or event, as pointed to by\n        entries in those tables.')
mteObjectsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 88, 1, 3, 1, 1), ).setIndexNames((0, "DISMAN-EVENT-MIB", "mteOwner"), (0, "DISMAN-EVENT-MIB", "mteObjectsName"), (0, "DISMAN-EVENT-MIB", "mteObjectsIndex"))
if mibBuilder.loadTexts: mteObjectsEntry.setDescription('A group of objects.  Applications create and delete entries\n        using mteObjectsEntryStatus.\n\n        When adding objects to a notification they are added in the\n        lexical order of their index in this table.  Those associated\n        with a trigger come first, then trigger test, then event.')
mteObjectsName = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 3, 1, 1, 1), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(1,32)))
if mibBuilder.loadTexts: mteObjectsName.setDescription('A locally-unique, administratively assigned name for a group\n        of objects.')
mteObjectsIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 3, 1, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: mteObjectsIndex.setDescription('An arbitrary integer for the purpose of identifying\n        individual objects within a mteObjectsName group.\n\n        Objects within a group are placed in the notification in the\n        numerical order of this index.\n\n        Groups are placed in the notification in the order of the\n        selections for overall trigger, trigger test, and event.\n        Within trigger test they are in the same order as the\n        numerical values of the bits defined for mteTriggerTest.\n\n        Bad object identifiers or a mismatch between truncating the\n        identifier and the value of mteDeltaDiscontinuityIDWildcard\n        result in operation as one would expect when providing the\n        wrong identifier to a Get operation.  The Get will fail or get\n        the wrong object.  If the object is not available it is omitted\n        from the notification.')
mteObjectsID = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 3, 1, 1, 3), ObjectIdentifier().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteObjectsID.setDescription("The object identifier of a MIB object to add to a\n        Notification that results from the firing of a trigger.\n\n        This may be wildcarded by truncating all or part of the\n        instance portion, in which case the instance portion of the\n        OID for obtaining this object will be the same as that used\n        in obtaining the mteTriggerValueID that fired.  If such\n        wildcarding is applied, mteObjectsIDWildcard must be\n        'true' and if not it must be 'false'.\n        Each instance that fills the wildcard is independent of any\n        additional instances, that is, wildcarded objects operate\n        as if there were a separate table entry for each instance\n        that fills the wildcard without having to actually predict\n        all possible instances ahead of time.")
mteObjectsIDWildcard = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 3, 1, 1, 4), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteObjectsIDWildcard.setDescription("Control for whether mteObjectsID is to be treated as\n        fully-specified or wildcarded, with 'true' indicating wildcard.")
mteObjectsEntryStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 3, 1, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteObjectsEntryStatus.setDescription('The control that allows creation and deletion of entries.\n        Once made active an entry MAY not be modified except to\n        delete it.')
mteObjectsEntryStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 3, 1, 1, 6), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteObjectsEntryStorageType.setDescription("The storage type for this conceptual row.\n                 Conceptual rows having the value 'permanent' need not\n                 allow write-access to any columnar objects in the row.\n                ")
mteEventFailures = MibScalar((1, 3, 6, 1, 2, 1, 88, 1, 4, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mteEventFailures.setDescription('The number of times an attempt to invoke an event\n        has failed.  This counts individually for each\n        attempt in a group of targets or each attempt for a\n        wildcarded trigger object.')
mteEventTable = MibTable((1, 3, 6, 1, 2, 1, 88, 1, 4, 2), )
if mibBuilder.loadTexts: mteEventTable.setDescription('A table of management event action information.')
mteEventEntry = MibTableRow((1, 3, 6, 1, 2, 1, 88, 1, 4, 2, 1), ).setIndexNames((0, "DISMAN-EVENT-MIB", "mteOwner"), (1, "DISMAN-EVENT-MIB", "mteEventName"))
if mibBuilder.loadTexts: mteEventEntry.setDescription('Information about a single event.  Applications create and\n        delete entries using mteEventEntryStatus.')
mteEventName = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 4, 2, 1, 1), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(1,32)))
if mibBuilder.loadTexts: mteEventName.setDescription('A locally-unique, administratively assigned name for the\n        event.')
mteEventComment = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 4, 2, 1, 2), SnmpAdminString().clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteEventComment.setDescription("A description of the event's function and use.")
mteEventActions = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 4, 2, 1, 3), Bits().clone(namedValues=NamedValues(("notification", 0), ("set", 1),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteEventActions.setDescription("The actions to perform when this event occurs.\n\n        For 'notification', Traps and/or Informs are sent according\n        to the configuration in the SNMP Notification MIB.\n\n        For 'set', an SNMP Set operation is performed according to\n        control values in this entry.")
mteEventEnabled = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 4, 2, 1, 4), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteEventEnabled.setDescription("A control to allow an event to be configured but not used.\n        When the value is 'false' the event does not execute even if\n        triggered.")
mteEventEntryStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 4, 2, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteEventEntryStatus.setDescription('The control that allows creation and deletion of entries.\n        Once made active an entry MAY not be modified except to\n        modify the value of mteEventEnabled or to delete the entry.')
mteEventEntryStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 4, 2, 1, 6), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mteEventEntryStorageType.setDescription("The storage type for this conceptual row.\n                 Conceptual rows having the value 'permanent' need not\n                 allow write-access to any columnar objects in the row.\n                ")
mteEventNotificationTable = MibTable((1, 3, 6, 1, 2, 1, 88, 1, 4, 3), )
if mibBuilder.loadTexts: mteEventNotificationTable.setDescription('A table of information about notifications to be sent as a\n        consequence of management events.')
mteEventNotificationEntry = MibTableRow((1, 3, 6, 1, 2, 1, 88, 1, 4, 3, 1), ).setIndexNames((0, "DISMAN-EVENT-MIB", "mteOwner"), (1, "DISMAN-EVENT-MIB", "mteEventName"))
if mibBuilder.loadTexts: mteEventNotificationEntry.setDescription("Information about a single event's notification.  Entries\n        automatically exist in this this table for each mteEventEntry\n        that has 'notification' set in mteEventActions.")
mteEventNotification = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 4, 3, 1, 1), ObjectIdentifier().clone((0, 0))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteEventNotification.setDescription("The object identifier from the NOTIFICATION-TYPE for the\n        notification to use if mteEventActions has 'notification' set.")
mteEventNotificationObjectsOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 4, 3, 1, 2), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteEventNotificationObjectsOwner.setDescription('To go with mteEventNotificationObjects, the mteOwner of a\n        group of objects from mteObjectsTable.')
mteEventNotificationObjects = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 4, 3, 1, 3), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteEventNotificationObjects.setDescription("The mteObjectsName of a group of objects from\n        mteObjectsTable if mteEventActions has 'notification' set.\n        These objects are to be added to any Notification generated by\n        this event.\n\n        Objects may also be added based on the trigger that stimulated\n        the event.\n\n        A length of 0 indicates no additional objects.")
mteEventSetTable = MibTable((1, 3, 6, 1, 2, 1, 88, 1, 4, 4), )
if mibBuilder.loadTexts: mteEventSetTable.setDescription('A table of management event action information.')
mteEventSetEntry = MibTableRow((1, 3, 6, 1, 2, 1, 88, 1, 4, 4, 1), ).setIndexNames((0, "DISMAN-EVENT-MIB", "mteOwner"), (1, "DISMAN-EVENT-MIB", "mteEventName"))
if mibBuilder.loadTexts: mteEventSetEntry.setDescription("Information about a single event's set option.  Entries\n        automatically exist in this this table for each mteEventEntry\n        that has 'set' set in mteEventActions.")
mteEventSetObject = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 4, 4, 1, 1), ObjectIdentifier().clone((0, 0))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteEventSetObject.setDescription("The object identifier from the MIB object to set if\n        mteEventActions has 'set' set.\n\n        This object identifier may be wildcarded by leaving\n        sub-identifiers off the end, in which case\n        nteEventSetObjectWildCard must be 'true'.\n\n        If mteEventSetObject is wildcarded the instance used to set the\n        object to which it points is the same as the instance from the\n        value of mteTriggerValueID that triggered the event.\n\n        Each instance that fills the wildcard is independent of any\n        additional instances, that is, wildcarded objects operate\n        as if there were a separate table entry for each instance\n        that fills the wildcard without having to actually predict\n        all possible instances ahead of time.\n\n        Bad object identifiers or a mismatch between truncating the\n        identifier and the value of mteSetObjectWildcard\n        result in operation as one would expect when providing the\n        wrong identifier to a Set operation.  The Set will fail or set\n        the wrong object.  If the value syntax of the destination\n        object is not correct, the Set fails with the normal SNMP\n        error code.")
mteEventSetObjectWildcard = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 4, 4, 1, 2), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteEventSetObjectWildcard.setDescription("Control over whether mteEventSetObject is to be treated as\n        fully-specified or wildcarded, with 'true' indicating wildcard\n        if mteEventActions has 'set' set.")
mteEventSetValue = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 4, 4, 1, 3), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteEventSetValue.setDescription("The value to which to set the object at mteEventSetObject\n        if mteEventActions has 'set' set.")
mteEventSetTargetTag = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 4, 4, 1, 4), SnmpTagValue().clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteEventSetTargetTag.setDescription("The tag for the target(s) at which to set the object at\n        mteEventSetObject to mteEventSetValue if mteEventActions\n        has 'set' set.\n\n        Systems limited to self management MAY reject a non-zero\n        length for the value of this object.\n\n        A length of 0 indicates the local system.  In this case,\n        access to the objects indicated by mteEventSetObject is under\n        the security credentials of the requester that set\n        mteTriggerEntryStatus to 'active'.  Those credentials are the\n        input parameters for isAccessAllowed from the Architecture for\n        Describing SNMP Management Frameworks.\n\n        Otherwise access rights are checked according to the security\n        parameters resulting from the tag.")
mteEventSetContextName = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 4, 4, 1, 5), SnmpAdminString().clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteEventSetContextName.setDescription("The management context in which to set mteEventObjectID.\n        if mteEventActions has 'set' set.\n\n        This may be wildcarded by leaving characters off the end.  To\n        indicate such wildcarding mteEventSetContextNameWildcard must\n        be 'true'.\n\n        If this context name is wildcarded the value used to complete\n        the wildcarding of mteTriggerContextName will be appended.")
mteEventSetContextNameWildcard = MibTableColumn((1, 3, 6, 1, 2, 1, 88, 1, 4, 4, 1, 6), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mteEventSetContextNameWildcard.setDescription("Control for whether mteEventSetContextName is to be treated as\n        fully-specified or wildcarded, with 'true' indicating wildcard\n        if mteEventActions has 'set' set.")
dismanEventMIBNotificationPrefix = MibIdentifier((1, 3, 6, 1, 2, 1, 88, 2))
dismanEventMIBNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 88, 2, 0))
dismanEventMIBNotificationObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 88, 2, 1))
mteHotTrigger = MibScalar((1, 3, 6, 1, 2, 1, 88, 2, 1, 1), SnmpAdminString()).setMaxAccess("accessiblefornotify")
if mibBuilder.loadTexts: mteHotTrigger.setDescription('The name of the trigger causing the notification.')
mteHotTargetName = MibScalar((1, 3, 6, 1, 2, 1, 88, 2, 1, 2), SnmpAdminString()).setMaxAccess("accessiblefornotify")
if mibBuilder.loadTexts: mteHotTargetName.setDescription("The SNMP Target MIB's snmpTargetAddrName related to the\n        notification.")
mteHotContextName = MibScalar((1, 3, 6, 1, 2, 1, 88, 2, 1, 3), SnmpAdminString()).setMaxAccess("accessiblefornotify")
if mibBuilder.loadTexts: mteHotContextName.setDescription('The context name related to the notification.  This MUST be as\n        fully-qualified as possible, including filling in wildcard\n        information determined in processing.')
mteHotOID = MibScalar((1, 3, 6, 1, 2, 1, 88, 2, 1, 4), ObjectIdentifier()).setMaxAccess("accessiblefornotify")
if mibBuilder.loadTexts: mteHotOID.setDescription('The object identifier of the destination object related to the\n        notification.  This MUST be as fully-qualified as possible,\n        including filling in wildcard information determined in\n        processing.\n\n        For a trigger-related notification this is from\n        mteTriggerValueID.\n\n        For a set failure this is from mteEventSetObject.')
mteHotValue = MibScalar((1, 3, 6, 1, 2, 1, 88, 2, 1, 5), Integer32()).setMaxAccess("accessiblefornotify")
if mibBuilder.loadTexts: mteHotValue.setDescription('The value of the object at mteTriggerValueID when a\n        trigger fired.')
mteFailedReason = MibScalar((1, 3, 6, 1, 2, 1, 88, 2, 1, 6), FailureReason()).setMaxAccess("accessiblefornotify")
if mibBuilder.loadTexts: mteFailedReason.setDescription('The reason for the failure of an attempt to check for a\n        trigger condition or set an object in response to an event.')
mteTriggerFired = NotificationType((1, 3, 6, 1, 2, 1, 88, 2, 0, 1)).setObjects(*(("DISMAN-EVENT-MIB", "mteHotTrigger"), ("DISMAN-EVENT-MIB", "mteHotTargetName"), ("DISMAN-EVENT-MIB", "mteHotContextName"), ("DISMAN-EVENT-MIB", "mteHotOID"), ("DISMAN-EVENT-MIB", "mteHotValue"),))
if mibBuilder.loadTexts: mteTriggerFired.setDescription("Notification that the trigger indicated by the object\n        instances has fired, for triggers with mteTriggerType\n        'boolean' or 'existence'.")
mteTriggerRising = NotificationType((1, 3, 6, 1, 2, 1, 88, 2, 0, 2)).setObjects(*(("DISMAN-EVENT-MIB", "mteHotTrigger"), ("DISMAN-EVENT-MIB", "mteHotTargetName"), ("DISMAN-EVENT-MIB", "mteHotContextName"), ("DISMAN-EVENT-MIB", "mteHotOID"), ("DISMAN-EVENT-MIB", "mteHotValue"),))
if mibBuilder.loadTexts: mteTriggerRising.setDescription("Notification that the rising threshold was met for triggers\n        with mteTriggerType 'threshold'.")
mteTriggerFalling = NotificationType((1, 3, 6, 1, 2, 1, 88, 2, 0, 3)).setObjects(*(("DISMAN-EVENT-MIB", "mteHotTrigger"), ("DISMAN-EVENT-MIB", "mteHotTargetName"), ("DISMAN-EVENT-MIB", "mteHotContextName"), ("DISMAN-EVENT-MIB", "mteHotOID"), ("DISMAN-EVENT-MIB", "mteHotValue"),))
if mibBuilder.loadTexts: mteTriggerFalling.setDescription("Notification that the falling threshold was met for triggers\n        with mteTriggerType 'threshold'.")
mteTriggerFailure = NotificationType((1, 3, 6, 1, 2, 1, 88, 2, 0, 4)).setObjects(*(("DISMAN-EVENT-MIB", "mteHotTrigger"), ("DISMAN-EVENT-MIB", "mteHotTargetName"), ("DISMAN-EVENT-MIB", "mteHotContextName"), ("DISMAN-EVENT-MIB", "mteHotOID"), ("DISMAN-EVENT-MIB", "mteFailedReason"),))
if mibBuilder.loadTexts: mteTriggerFailure.setDescription('Notification that an attempt to check a trigger has failed.\n\n        The network manager must enable this notification only with\n        a certain fear and trembling, as it can easily crowd out more\n        important information.  It should be used only to help diagnose\n        a problem that has appeared in the error counters and can not\n        be found otherwise.')
mteEventSetFailure = NotificationType((1, 3, 6, 1, 2, 1, 88, 2, 0, 5)).setObjects(*(("DISMAN-EVENT-MIB", "mteHotTrigger"), ("DISMAN-EVENT-MIB", "mteHotTargetName"), ("DISMAN-EVENT-MIB", "mteHotContextName"), ("DISMAN-EVENT-MIB", "mteHotOID"), ("DISMAN-EVENT-MIB", "mteFailedReason"),))
if mibBuilder.loadTexts: mteEventSetFailure.setDescription('Notification that an attempt to do a set in response to an\n        event has failed.\n\n        The network manager must enable this notification only with\n        a certain fear and trembling, as it can easily crowd out more\n        important information.  It should be used only to help diagnose\n        a problem that has appeared in the error counters and can not\n        be found otherwise.')
dismanEventMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 88, 3))
dismanEventMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 88, 3, 1))
dismanEventMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 88, 3, 2))
dismanEventMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 88, 3, 1, 1)).setObjects(*(("DISMAN-EVENT-MIB", "dismanEventResourceGroup"), ("DISMAN-EVENT-MIB", "dismanEventTriggerGroup"), ("DISMAN-EVENT-MIB", "dismanEventObjectsGroup"), ("DISMAN-EVENT-MIB", "dismanEventEventGroup"), ("DISMAN-EVENT-MIB", "dismanEventNotificationObjectGroup"), ("DISMAN-EVENT-MIB", "dismanEventNotificationGroup"),))
if mibBuilder.loadTexts: dismanEventMIBCompliance.setDescription('The compliance statement for entities which implement\n                the Event MIB.')
dismanEventResourceGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 88, 3, 2, 1)).setObjects(*(("DISMAN-EVENT-MIB", "mteResourceSampleMinimum"), ("DISMAN-EVENT-MIB", "mteResourceSampleInstanceMaximum"), ("DISMAN-EVENT-MIB", "mteResourceSampleInstances"), ("DISMAN-EVENT-MIB", "mteResourceSampleInstancesHigh"), ("DISMAN-EVENT-MIB", "mteResourceSampleInstanceLacks"),))
if mibBuilder.loadTexts: dismanEventResourceGroup.setDescription('Event resource status and control objects.')
dismanEventTriggerGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 88, 3, 2, 2)).setObjects(*(("DISMAN-EVENT-MIB", "mteTriggerFailures"), ("DISMAN-EVENT-MIB", "mteTriggerComment"), ("DISMAN-EVENT-MIB", "mteTriggerTest"), ("DISMAN-EVENT-MIB", "mteTriggerSampleType"), ("DISMAN-EVENT-MIB", "mteTriggerValueID"), ("DISMAN-EVENT-MIB", "mteTriggerValueIDWildcard"), ("DISMAN-EVENT-MIB", "mteTriggerTargetTag"), ("DISMAN-EVENT-MIB", "mteTriggerContextName"), ("DISMAN-EVENT-MIB", "mteTriggerContextNameWildcard"), ("DISMAN-EVENT-MIB", "mteTriggerFrequency"), ("DISMAN-EVENT-MIB", "mteTriggerObjectsOwner"), ("DISMAN-EVENT-MIB", "mteTriggerObjects"), ("DISMAN-EVENT-MIB", "mteTriggerEnabled"), ("DISMAN-EVENT-MIB", "mteTriggerEntryStatus"), ("DISMAN-EVENT-MIB", "mteTriggerEntryStorageType"), ("DISMAN-EVENT-MIB", "mteTriggerDeltaDiscontinuityID"), ("DISMAN-EVENT-MIB", "mteTriggerDeltaDiscontinuityIDWildcard"), ("DISMAN-EVENT-MIB", "mteTriggerDeltaDiscontinuityIDType"), ("DISMAN-EVENT-MIB", "mteTriggerExistenceTest"), ("DISMAN-EVENT-MIB", "mteTriggerExistenceStartup"), ("DISMAN-EVENT-MIB", "mteTriggerExistenceObjectsOwner"), ("DISMAN-EVENT-MIB", "mteTriggerExistenceObjects"), ("DISMAN-EVENT-MIB", "mteTriggerExistenceEventOwner"), ("DISMAN-EVENT-MIB", "mteTriggerExistenceEvent"), ("DISMAN-EVENT-MIB", "mteTriggerBooleanComparison"), ("DISMAN-EVENT-MIB", "mteTriggerBooleanValue"), ("DISMAN-EVENT-MIB", "mteTriggerBooleanStartup"), ("DISMAN-EVENT-MIB", "mteTriggerBooleanObjectsOwner"), ("DISMAN-EVENT-MIB", "mteTriggerBooleanObjects"), ("DISMAN-EVENT-MIB", "mteTriggerBooleanEventOwner"), ("DISMAN-EVENT-MIB", "mteTriggerBooleanEvent"), ("DISMAN-EVENT-MIB", "mteTriggerThresholdStartup"), ("DISMAN-EVENT-MIB", "mteTriggerThresholdObjectsOwner"), ("DISMAN-EVENT-MIB", "mteTriggerThresholdObjects"), ("DISMAN-EVENT-MIB", "mteTriggerThresholdRising"), ("DISMAN-EVENT-MIB", "mteTriggerThresholdFalling"), ("DISMAN-EVENT-MIB", "mteTriggerThresholdDeltaRising"), ("DISMAN-EVENT-MIB", "mteTriggerThresholdDeltaFalling"), ("DISMAN-EVENT-MIB", "mteTriggerThresholdRisingEventOwner"), ("DISMAN-EVENT-MIB", "mteTriggerThresholdRisingEvent"), ("DISMAN-EVENT-MIB", "mteTriggerThresholdFallingEventOwner"), ("DISMAN-EVENT-MIB", "mteTriggerThresholdFallingEvent"), ("DISMAN-EVENT-MIB", "mteTriggerThresholdDeltaRisingEventOwner"), ("DISMAN-EVENT-MIB", "mteTriggerThresholdDeltaRisingEvent"), ("DISMAN-EVENT-MIB", "mteTriggerThresholdDeltaFallingEventOwner"), ("DISMAN-EVENT-MIB", "mteTriggerThresholdDeltaFallingEvent"),))
if mibBuilder.loadTexts: dismanEventTriggerGroup.setDescription('Event triggers.')
dismanEventObjectsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 88, 3, 2, 3)).setObjects(*(("DISMAN-EVENT-MIB", "mteObjectsID"), ("DISMAN-EVENT-MIB", "mteObjectsIDWildcard"), ("DISMAN-EVENT-MIB", "mteObjectsEntryStatus"), ("DISMAN-EVENT-MIB", "mteObjectsEntryStorageType"),))
if mibBuilder.loadTexts: dismanEventObjectsGroup.setDescription('Supplemental objects.')
dismanEventEventGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 88, 3, 2, 4)).setObjects(*(("DISMAN-EVENT-MIB", "mteEventFailures"), ("DISMAN-EVENT-MIB", "mteEventComment"), ("DISMAN-EVENT-MIB", "mteEventActions"), ("DISMAN-EVENT-MIB", "mteEventEnabled"), ("DISMAN-EVENT-MIB", "mteEventEntryStatus"), ("DISMAN-EVENT-MIB", "mteEventEntryStorageType"), ("DISMAN-EVENT-MIB", "mteEventNotification"), ("DISMAN-EVENT-MIB", "mteEventNotificationObjectsOwner"), ("DISMAN-EVENT-MIB", "mteEventNotificationObjects"), ("DISMAN-EVENT-MIB", "mteEventSetObject"), ("DISMAN-EVENT-MIB", "mteEventSetObjectWildcard"), ("DISMAN-EVENT-MIB", "mteEventSetValue"), ("DISMAN-EVENT-MIB", "mteEventSetTargetTag"), ("DISMAN-EVENT-MIB", "mteEventSetContextName"), ("DISMAN-EVENT-MIB", "mteEventSetContextNameWildcard"),))
if mibBuilder.loadTexts: dismanEventEventGroup.setDescription('Events.')
dismanEventNotificationObjectGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 88, 3, 2, 5)).setObjects(*(("DISMAN-EVENT-MIB", "mteHotTrigger"), ("DISMAN-EVENT-MIB", "mteHotTargetName"), ("DISMAN-EVENT-MIB", "mteHotContextName"), ("DISMAN-EVENT-MIB", "mteHotOID"), ("DISMAN-EVENT-MIB", "mteHotValue"), ("DISMAN-EVENT-MIB", "mteFailedReason"),))
if mibBuilder.loadTexts: dismanEventNotificationObjectGroup.setDescription('Notification objects.')
dismanEventNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 88, 3, 2, 6)).setObjects(*(("DISMAN-EVENT-MIB", "mteTriggerFired"), ("DISMAN-EVENT-MIB", "mteTriggerRising"), ("DISMAN-EVENT-MIB", "mteTriggerFalling"), ("DISMAN-EVENT-MIB", "mteTriggerFailure"), ("DISMAN-EVENT-MIB", "mteEventSetFailure"),))
if mibBuilder.loadTexts: dismanEventNotificationGroup.setDescription('Notifications.')
mibBuilder.exportSymbols("DISMAN-EVENT-MIB", mteTriggerThresholdDeltaRisingEventOwner=mteTriggerThresholdDeltaRisingEventOwner, mteTriggerValueIDWildcard=mteTriggerValueIDWildcard, dismanEventMIBNotifications=dismanEventMIBNotifications, mteTriggerBooleanTable=mteTriggerBooleanTable, mteHotTargetName=mteHotTargetName, mteTriggerBooleanObjectsOwner=mteTriggerBooleanObjectsOwner, mteEventFailures=mteEventFailures, mteEventEntryStorageType=mteEventEntryStorageType, mteTriggerName=mteTriggerName, mteTriggerDeltaTable=mteTriggerDeltaTable, mteTriggerDeltaEntry=mteTriggerDeltaEntry, mteEventSetObject=mteEventSetObject, mteHotOID=mteHotOID, mteTriggerFailures=mteTriggerFailures, mteTriggerExistenceObjectsOwner=mteTriggerExistenceObjectsOwner, mteTriggerBooleanComparison=mteTriggerBooleanComparison, mteTriggerBooleanStartup=mteTriggerBooleanStartup, mteEventSetFailure=mteEventSetFailure, mteEventEntry=mteEventEntry, mteTriggerExistenceStartup=mteTriggerExistenceStartup, dismanEventMIB=dismanEventMIB, mteTriggerExistenceTest=mteTriggerExistenceTest, mteEventNotificationObjectsOwner=mteEventNotificationObjectsOwner, mteTriggerContextName=mteTriggerContextName, mteResourceSampleInstancesHigh=mteResourceSampleInstancesHigh, mteResource=mteResource, mteTriggerBooleanEventOwner=mteTriggerBooleanEventOwner, mteObjectsIndex=mteObjectsIndex, mteEventComment=mteEventComment, mteTriggerBooleanObjects=mteTriggerBooleanObjects, mteObjectsEntry=mteObjectsEntry, mteObjectsID=mteObjectsID, mteEventSetContextNameWildcard=mteEventSetContextNameWildcard, mteTriggerThresholdStartup=mteTriggerThresholdStartup, mteEvent=mteEvent, dismanEventNotificationGroup=dismanEventNotificationGroup, mteEventActions=mteEventActions, FailureReason=FailureReason, mteTriggerExistenceEvent=mteTriggerExistenceEvent, mteEventTable=mteEventTable, mteResourceSampleInstanceMaximum=mteResourceSampleInstanceMaximum, dismanEventMIBConformance=dismanEventMIBConformance, mteEventSetTable=mteEventSetTable, mteTrigger=mteTrigger, mteTriggerFired=mteTriggerFired, mteResourceSampleInstances=mteResourceSampleInstances, mteTriggerObjectsOwner=mteTriggerObjectsOwner, mteTriggerExistenceEntry=mteTriggerExistenceEntry, mteEventSetTargetTag=mteEventSetTargetTag, mteEventEnabled=mteEventEnabled, mteTriggerDeltaDiscontinuityID=mteTriggerDeltaDiscontinuityID, mteTriggerEntryStatus=mteTriggerEntryStatus, mteTriggerTest=mteTriggerTest, mteHotValue=mteHotValue, mteHotTrigger=mteHotTrigger, mteTriggerBooleanValue=mteTriggerBooleanValue, mteEventSetObjectWildcard=mteEventSetObjectWildcard, mteTriggerExistenceObjects=mteTriggerExistenceObjects, mteOwner=mteOwner, dismanEventMIBCompliances=dismanEventMIBCompliances, sysUpTimeInstance=sysUpTimeInstance, mteObjects=mteObjects, mteTriggerValueID=mteTriggerValueID, mteTriggerFailure=mteTriggerFailure, mteTriggerTargetTag=mteTriggerTargetTag, dismanEventTriggerGroup=dismanEventTriggerGroup, dismanEventMIBCompliance=dismanEventMIBCompliance, mteTriggerEnabled=mteTriggerEnabled, mteTriggerThresholdObjects=mteTriggerThresholdObjects, mteTriggerThresholdObjectsOwner=mteTriggerThresholdObjectsOwner, mteTriggerThresholdTable=mteTriggerThresholdTable, dismanEventEventGroup=dismanEventEventGroup, mteEventEntryStatus=mteEventEntryStatus, mteEventSetValue=mteEventSetValue, mteResourceSampleInstanceLacks=mteResourceSampleInstanceLacks, mteTriggerSampleType=mteTriggerSampleType, mteEventNotificationTable=mteEventNotificationTable, mteObjectsTable=mteObjectsTable, mteTriggerThresholdDeltaRising=mteTriggerThresholdDeltaRising, mteTriggerThresholdDeltaFalling=mteTriggerThresholdDeltaFalling, mteTriggerExistenceTable=mteTriggerExistenceTable, dismanEventObjectsGroup=dismanEventObjectsGroup, mteEventSetContextName=mteEventSetContextName, mteTriggerDeltaDiscontinuityIDType=mteTriggerDeltaDiscontinuityIDType, dismanEventMIBGroups=dismanEventMIBGroups, mteResourceSampleMinimum=mteResourceSampleMinimum, mteTriggerThresholdFallingEvent=mteTriggerThresholdFallingEvent, mteTriggerFrequency=mteTriggerFrequency, mteTriggerContextNameWildcard=mteTriggerContextNameWildcard, mteTriggerEntryStorageType=mteTriggerEntryStorageType, mteTriggerDeltaDiscontinuityIDWildcard=mteTriggerDeltaDiscontinuityIDWildcard, mteTriggerThresholdFallingEventOwner=mteTriggerThresholdFallingEventOwner, mteTriggerThresholdRisingEvent=mteTriggerThresholdRisingEvent, mteTriggerBooleanEvent=mteTriggerBooleanEvent, mteEventNotificationEntry=mteEventNotificationEntry, mteEventNotification=mteEventNotification, mteTriggerThresholdRisingEventOwner=mteTriggerThresholdRisingEventOwner, mteTriggerThresholdDeltaRisingEvent=mteTriggerThresholdDeltaRisingEvent, dismanEventNotificationObjectGroup=dismanEventNotificationObjectGroup, mteObjectsEntryStorageType=mteObjectsEntryStorageType, dismanEventResourceGroup=dismanEventResourceGroup, mteHotContextName=mteHotContextName, mteTriggerThresholdDeltaFallingEvent=mteTriggerThresholdDeltaFallingEvent, mteEventSetEntry=mteEventSetEntry, mteTriggerBooleanEntry=mteTriggerBooleanEntry, mteObjectsIDWildcard=mteObjectsIDWildcard, mteObjectsName=mteObjectsName, mteFailedReason=mteFailedReason, mteTriggerObjects=mteTriggerObjects, dismanEventMIBObjects=dismanEventMIBObjects, dismanEventMIBNotificationPrefix=dismanEventMIBNotificationPrefix, mteTriggerTable=mteTriggerTable, mteObjectsEntryStatus=mteObjectsEntryStatus, mteTriggerExistenceEventOwner=mteTriggerExistenceEventOwner, mteTriggerThresholdRising=mteTriggerThresholdRising, mteEventName=mteEventName, PYSNMP_MODULE_ID=dismanEventMIB, mteTriggerThresholdDeltaFallingEventOwner=mteTriggerThresholdDeltaFallingEventOwner, mteTriggerFalling=mteTriggerFalling, mteTriggerThresholdFalling=mteTriggerThresholdFalling, mteEventNotificationObjects=mteEventNotificationObjects, mteTriggerThresholdEntry=mteTriggerThresholdEntry, dismanEventMIBNotificationObjects=dismanEventMIBNotificationObjects, mteTriggerEntry=mteTriggerEntry, mteTriggerRising=mteTriggerRising, mteTriggerComment=mteTriggerComment)



#
# PySNMP MIB module IPV6-TCP-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/IPV6-TCP-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:18:45 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ValueSizeConstraint, ValueRangeConstraint, SingleValueConstraint, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ValueSizeConstraint", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsUnion")
( Ipv6IfIndexOrZero, Ipv6Address, ) = mibBuilder.importSymbols("IPV6-TC", "Ipv6IfIndexOrZero", "Ipv6Address")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( mib_2, IpAddress, Bits, Gauge32, MibIdentifier, ModuleIdentity, ObjectIdentity, iso, TimeTicks, Integer32, Counter64, Counter32, MibScalar, MibTable, MibTableRow, MibTableColumn, NotificationType, experimental, Unsigned32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "mib-2", "IpAddress", "Bits", "Gauge32", "MibIdentifier", "ModuleIdentity", "ObjectIdentity", "iso", "TimeTicks", "Integer32", "Counter64", "Counter32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "NotificationType", "experimental", "Unsigned32")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
ipv6TcpMIB = ModuleIdentity((1, 3, 6, 1, 3, 86))
if mibBuilder.loadTexts: ipv6TcpMIB.setLastUpdated('9801290000Z')
if mibBuilder.loadTexts: ipv6TcpMIB.setOrganization('IETF IPv6 MIB Working Group')
if mibBuilder.loadTexts: ipv6TcpMIB.setContactInfo('       Mike Daniele\n    \n                    Postal: Compaq Computer Corporation\n                            110 Spitbrook Rd\n                            Nashua, NH 03062.\n                            US\n    \n                    Phone:  +1 603 884 1423\n                    Email:  daniele@zk3.dec.com')
if mibBuilder.loadTexts: ipv6TcpMIB.setDescription('The MIB module for entities implementing TCP over IPv6.')
tcp = MibIdentifier((1, 3, 6, 1, 2, 1, 6))
ipv6TcpConnTable = MibTable((1, 3, 6, 1, 2, 1, 6, 16), )
if mibBuilder.loadTexts: ipv6TcpConnTable.setDescription('A table containing TCP connection-specific information,\n            for only those connections whose endpoints are IPv6 addresses.')
ipv6TcpConnEntry = MibTableRow((1, 3, 6, 1, 2, 1, 6, 16, 1), ).setIndexNames((0, "IPV6-TCP-MIB", "ipv6TcpConnLocalAddress"), (0, "IPV6-TCP-MIB", "ipv6TcpConnLocalPort"), (0, "IPV6-TCP-MIB", "ipv6TcpConnRemAddress"), (0, "IPV6-TCP-MIB", "ipv6TcpConnRemPort"), (0, "IPV6-TCP-MIB", "ipv6TcpConnIfIndex"))
if mibBuilder.loadTexts: ipv6TcpConnEntry.setDescription('A conceptual row of the ipv6TcpConnTable containing\n            information about a particular current TCP connection.\n            Each row of this table is transient, in that it ceases to\n            exist when (or soon after) the connection makes the transition\n            to the CLOSED state.\n    \n            Note that conceptual rows in this table require an additional\n            index object compared to tcpConnTable, since IPv6 addresses\n            are not guaranteed to be unique on the managed node.')
ipv6TcpConnLocalAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 16, 1, 1), Ipv6Address())
if mibBuilder.loadTexts: ipv6TcpConnLocalAddress.setDescription('The local IPv6 address for this TCP connection. In\n            the case of a connection in the listen state which\n            is willing to accept connections for any IPv6\n            address associated with the managed node, the value\n            ::0 is used.')
ipv6TcpConnLocalPort = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 16, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)))
if mibBuilder.loadTexts: ipv6TcpConnLocalPort.setDescription('The local port number for this TCP connection.')
ipv6TcpConnRemAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 16, 1, 3), Ipv6Address())
if mibBuilder.loadTexts: ipv6TcpConnRemAddress.setDescription('The remote IPv6 address for this TCP connection.')
ipv6TcpConnRemPort = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 16, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)))
if mibBuilder.loadTexts: ipv6TcpConnRemPort.setDescription('The remote port number for this TCP connection.')
ipv6TcpConnIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 16, 1, 5), Ipv6IfIndexOrZero())
if mibBuilder.loadTexts: ipv6TcpConnIfIndex.setDescription("An index object used to disambiguate conceptual rows in\n            the table, since the connection 4-tuple may not be unique.\n    \n            If the connection's remote address (ipv6TcpConnRemAddress)\n            is a link-local address and the connection's local address\n            (ipv6TcpConnLocalAddress) is not a link-local address, this\n            object identifies a local interface on the same link as\n            the connection's remote link-local address.\n    \n            Otherwise, this object identifies the local interface that\n            is associated with the ipv6TcpConnLocalAddress for this\n            TCP connection.  If such a local interface cannot be determined,\n            this object should take on the value 0.  (A possible example\n            of this would be if the value of ipv6TcpConnLocalAddress is ::0.)\n    \n            The interface identified by a particular non-0 value of this\n            index is the same interface as identified by the same value\n            of ipv6IfIndex.\n    \n            The value of this object must remain constant during the life\n            of the TCP connection.")
ipv6TcpConnState = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 16, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,))).clone(namedValues=NamedValues(("closed", 1), ("listen", 2), ("synSent", 3), ("synReceived", 4), ("established", 5), ("finWait1", 6), ("finWait2", 7), ("closeWait", 8), ("lastAck", 9), ("closing", 10), ("timeWait", 11), ("deleteTCB", 12),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ipv6TcpConnState.setDescription("The state of this TCP connection.\n    \n            The only value which may be set by a management station is\n            deleteTCB(12).  Accordingly, it is appropriate for an agent\n            to return an error response (`badValue' for SNMPv1, 'wrongValue'\n            for SNMPv2) if a management station attempts to set this\n            object to any other value.\n    \n            If a management station sets this object to the value\n            deleteTCB(12), then this has the effect of deleting the TCB\n            (as defined in RFC 793) of the corresponding connection on\n            the managed node, resulting in immediate termination of the\n            connection.\n    \n            As an implementation-specific option, a RST segment may be\n            sent from the managed node to the other TCP endpoint (note\n            however that RST segments are not sent reliably).")
ipv6TcpConformance = MibIdentifier((1, 3, 6, 1, 3, 86, 2))
ipv6TcpCompliances = MibIdentifier((1, 3, 6, 1, 3, 86, 2, 1))
ipv6TcpGroups = MibIdentifier((1, 3, 6, 1, 3, 86, 2, 2))
ipv6TcpCompliance = ModuleCompliance((1, 3, 6, 1, 3, 86, 2, 1, 1)).setObjects(*(("IPV6-TCP-MIB", "ipv6TcpGroup"),))
if mibBuilder.loadTexts: ipv6TcpCompliance.setDescription('The compliance statement for SNMPv2 entities which\n            implement TCP over IPv6.')
ipv6TcpGroup = ObjectGroup((1, 3, 6, 1, 3, 86, 2, 2, 1)).setObjects(*(("IPV6-TCP-MIB", "ipv6TcpConnState"),))
if mibBuilder.loadTexts: ipv6TcpGroup.setDescription('The group of objects providing management of\n            TCP over IPv6.')
mibBuilder.exportSymbols("IPV6-TCP-MIB", ipv6TcpConformance=ipv6TcpConformance, ipv6TcpMIB=ipv6TcpMIB, ipv6TcpCompliance=ipv6TcpCompliance, ipv6TcpConnRemAddress=ipv6TcpConnRemAddress, PYSNMP_MODULE_ID=ipv6TcpMIB, ipv6TcpConnState=ipv6TcpConnState, ipv6TcpConnTable=ipv6TcpConnTable, ipv6TcpConnLocalPort=ipv6TcpConnLocalPort, tcp=tcp, ipv6TcpConnRemPort=ipv6TcpConnRemPort, ipv6TcpConnLocalAddress=ipv6TcpConnLocalAddress, ipv6TcpGroup=ipv6TcpGroup, ipv6TcpConnIfIndex=ipv6TcpConnIfIndex, ipv6TcpCompliances=ipv6TcpCompliances, ipv6TcpConnEntry=ipv6TcpConnEntry, ipv6TcpGroups=ipv6TcpGroups)



#
# PySNMP MIB module RADIUS-AUTH-CLIENT-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/RADIUS-AUTH-CLIENT-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:25:31 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ValueSizeConstraint, ConstraintsIntersection, ConstraintsUnion, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ValueSizeConstraint", "ConstraintsIntersection", "ConstraintsUnion", "SingleValueConstraint")
( InetAddressType, InetAddress, InetPortNumber, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddressType", "InetAddress", "InetPortNumber")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( MibIdentifier, ObjectIdentity, TimeTicks, Gauge32, mib_2, Bits, Integer32, Unsigned32, ModuleIdentity, IpAddress, NotificationType, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter64, iso, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibIdentifier", "ObjectIdentity", "TimeTicks", "Gauge32", "mib-2", "Bits", "Integer32", "Unsigned32", "ModuleIdentity", "IpAddress", "NotificationType", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter64", "iso", "Counter32")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
radiusAuthClientMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 67, 1, 2)).setRevisions(("2006-08-21 00:00", "1999-06-11 00:00",))
if mibBuilder.loadTexts: radiusAuthClientMIB.setLastUpdated('200608210000Z')
if mibBuilder.loadTexts: radiusAuthClientMIB.setOrganization('IETF RADIUS Extensions Working Group.')
if mibBuilder.loadTexts: radiusAuthClientMIB.setContactInfo(' Bernard Aboba\n                Microsoft\n                One Microsoft Way\n                Redmond, WA  98052\n\n                US\n                Phone: +1 425 936 6605\n                EMail: bernarda@microsoft.com')
if mibBuilder.loadTexts: radiusAuthClientMIB.setDescription('The MIB module for entities implementing the client\n              side of the Remote Authentication Dial-In User Service\n              (RADIUS) authentication protocol.  Copyright (C) The\n              Internet Society (2006).  This version of this MIB\n              module is part of RFC 4668; see the RFC itself for\n              full legal notices.')
radiusMIB = ObjectIdentity((1, 3, 6, 1, 2, 1, 67))
if mibBuilder.loadTexts: radiusMIB.setDescription('The OID assigned to RADIUS MIB work by the IANA.')
radiusAuthentication = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 1))
radiusAuthClientMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 1, 2, 1))
radiusAuthClient = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1))
radiusAuthClientInvalidServerAddresses = MibScalar((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 1), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientInvalidServerAddresses.setDescription('The number of RADIUS Access-Response packets\n             received from unknown addresses.')
radiusAuthClientIdentifier = MibScalar((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 2), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientIdentifier.setDescription('The NAS-Identifier of the RADIUS authentication client.\n              This is not necessarily the same as sysName in MIB II.')
radiusAuthServerTable = MibTable((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 3), )
if mibBuilder.loadTexts: radiusAuthServerTable.setDescription('The (conceptual) table listing the RADIUS authentication\n             servers with which the client shares a secret.')
radiusAuthServerEntry = MibTableRow((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 3, 1), ).setIndexNames((0, "RADIUS-AUTH-CLIENT-MIB", "radiusAuthServerIndex"))
if mibBuilder.loadTexts: radiusAuthServerEntry.setDescription('An entry (conceptual row) representing a RADIUS\n             authentication server with which the client shares\n             a secret.')
radiusAuthServerIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 3, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: radiusAuthServerIndex.setDescription('A number uniquely identifying each RADIUS\n             Authentication server with which this client\n             communicates.')
radiusAuthServerAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 3, 1, 2), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServerAddress.setDescription('The IP address of the RADIUS authentication server\n             referred to in this table entry.')
radiusAuthClientServerPortNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 3, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientServerPortNumber.setDescription('The UDP port the client is using to send requests to\n             this server.')
radiusAuthClientRoundTripTime = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 3, 1, 4), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientRoundTripTime.setDescription('The time interval (in hundredths of a second) between\n             the most recent Access-Reply/Access-Challenge and the\n             Access-Request that matched it from this RADIUS\n             authentication server.')
radiusAuthClientAccessRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 3, 1, 5), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientAccessRequests.setDescription('The number of RADIUS Access-Request packets sent\n             to this server.  This does not include retransmissions.')
radiusAuthClientAccessRetransmissions = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 3, 1, 6), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientAccessRetransmissions.setDescription('The number of RADIUS Access-Request packets\n             retransmitted to this RADIUS authentication server.')
radiusAuthClientAccessAccepts = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 3, 1, 7), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientAccessAccepts.setDescription('The number of RADIUS Access-Accept packets\n             (valid or invalid) received from this server.')
radiusAuthClientAccessRejects = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 3, 1, 8), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientAccessRejects.setDescription('The number of RADIUS Access-Reject packets\n             (valid or invalid) received from this server.')
radiusAuthClientAccessChallenges = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 3, 1, 9), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientAccessChallenges.setDescription('The number of RADIUS Access-Challenge packets\n             (valid or invalid) received from this server.')
radiusAuthClientMalformedAccessResponses = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 3, 1, 10), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientMalformedAccessResponses.setDescription('The number of malformed RADIUS Access-Response\n             packets received from this server.\n             Malformed packets include packets with\n             an invalid length.  Bad authenticators or\n             Message Authenticator attributes or unknown types\n             are not included as malformed access responses.')
radiusAuthClientBadAuthenticators = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 3, 1, 11), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientBadAuthenticators.setDescription('The number of RADIUS Access-Response packets\n             containing invalid authenticators or Message\n             Authenticator attributes received from this server.')
radiusAuthClientPendingRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 3, 1, 12), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientPendingRequests.setDescription('The number of RADIUS Access-Request packets\n             destined for this server that have not yet timed out\n             or received a response.  This variable is incremented\n\n             when an Access-Request is sent and decremented due to\n             receipt of an Access-Accept, Access-Reject,\n             Access-Challenge, timeout, or retransmission.')
radiusAuthClientTimeouts = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 3, 1, 13), Counter32()).setUnits('timeouts').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientTimeouts.setDescription('The number of authentication timeouts to this server.\n             After a timeout, the client may retry to the same\n             server, send to a different server, or\n             give up.  A retry to the same server is counted as a\n             retransmit as well as a timeout.  A send to a different\n             server is counted as a Request as well as a timeout.')
radiusAuthClientUnknownTypes = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 3, 1, 14), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientUnknownTypes.setDescription('The number of RADIUS packets of unknown type that\n             were received from this server on the authentication\n             port.')
radiusAuthClientPacketsDropped = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 3, 1, 15), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientPacketsDropped.setDescription('The number of RADIUS packets that were\n             received from this server on the authentication port\n             and dropped for some other reason.')
radiusAuthServerExtTable = MibTable((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4), )
if mibBuilder.loadTexts: radiusAuthServerExtTable.setDescription('The (conceptual) table listing the RADIUS authentication\n             servers with which the client shares a secret.')
radiusAuthServerExtEntry = MibTableRow((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1), ).setIndexNames((0, "RADIUS-AUTH-CLIENT-MIB", "radiusAuthServerExtIndex"))
if mibBuilder.loadTexts: radiusAuthServerExtEntry.setDescription('An entry (conceptual row) representing a RADIUS\n             authentication server with which the client shares\n             a secret.')
radiusAuthServerExtIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: radiusAuthServerExtIndex.setDescription('A number uniquely identifying each RADIUS\n             Authentication server with which this client\n             communicates.')
radiusAuthServerInetAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1, 2), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServerInetAddressType.setDescription('The type of address format used for the\n             radiusAuthServerInetAddress object.')
radiusAuthServerInetAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1, 3), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthServerInetAddress.setDescription('The IP address of the RADIUS authentication\n             server referred to in this table entry, using\n             the version-neutral IP address format.')
radiusAuthClientServerInetPortNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1, 4), InetPortNumber().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientServerInetPortNumber.setDescription('The UDP port the client is using to send requests\n             to this server.  The value of zero (0) is invalid.')
radiusAuthClientExtRoundTripTime = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1, 5), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientExtRoundTripTime.setDescription('The time interval (in hundredths of a second) between\n             the most recent Access-Reply/Access-Challenge and the\n             Access-Request that matched it from this RADIUS\n             authentication server.')
radiusAuthClientExtAccessRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1, 6), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientExtAccessRequests.setDescription('The number of RADIUS Access-Request packets sent\n             to this server.  This does not include retransmissions.\n             This counter may experience a discontinuity when the\n             RADIUS Client module within the managed entity is\n             reinitialized, as indicated by the current value of\n             radiusAuthClientCounterDiscontinuity.')
radiusAuthClientExtAccessRetransmissions = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1, 7), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientExtAccessRetransmissions.setDescription('The number of RADIUS Access-Request packets\n             retransmitted to this RADIUS authentication server.\n             This counter may experience a discontinuity when\n             the RADIUS Client module within the managed entity\n             is reinitialized, as indicated by the current value\n             of radiusAuthClientCounterDiscontinuity.')
radiusAuthClientExtAccessAccepts = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1, 8), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientExtAccessAccepts.setDescription('The number of RADIUS Access-Accept packets\n             (valid or invalid) received from this server.\n             This counter may experience a discontinuity when\n             the RADIUS Client module within the managed entity\n             is reinitialized, as indicated by the current value\n\n             of radiusAuthClientCounterDiscontinuity.')
radiusAuthClientExtAccessRejects = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1, 9), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientExtAccessRejects.setDescription('The number of RADIUS Access-Reject packets\n             (valid or invalid) received from this server.\n             This counter may experience a discontinuity when\n             the RADIUS Client module within the managed\n             entity is reinitialized, as indicated by the\n             current value of\n             radiusAuthClientCounterDiscontinuity.')
radiusAuthClientExtAccessChallenges = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1, 10), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientExtAccessChallenges.setDescription('The number of RADIUS Access-Challenge packets\n             (valid or invalid) received from this server.\n             This counter may experience a discontinuity when\n             the RADIUS Client module within the managed\n             entity is reinitialized, as indicated by the\n             current value of\n             radiusAuthClientCounterDiscontinuity.')
radiusAuthClientExtMalformedAccessResponses = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1, 11), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientExtMalformedAccessResponses.setDescription('The number of malformed RADIUS Access-Response\n             packets received from this server.\n             Malformed packets include packets with\n\n             an invalid length.  Bad authenticators or\n             Message Authenticator attributes or unknown types\n             are not included as malformed access responses.\n             This counter may experience a discontinuity when\n             the RADIUS Client module within the managed entity\n             is reinitialized, as indicated by the current value\n             of radiusAuthClientCounterDiscontinuity.')
radiusAuthClientExtBadAuthenticators = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1, 12), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientExtBadAuthenticators.setDescription('The number of RADIUS Access-Response packets\n             containing invalid authenticators or Message\n             Authenticator attributes received from this server.\n             This counter may experience a discontinuity when\n             the RADIUS Client module within the managed entity\n             is reinitialized, as indicated by the current value\n             of radiusAuthClientCounterDiscontinuity.')
radiusAuthClientExtPendingRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1, 13), Gauge32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientExtPendingRequests.setDescription('The number of RADIUS Access-Request packets\n             destined for this server that have not yet timed out\n             or received a response.  This variable is incremented\n             when an Access-Request is sent and decremented due to\n             receipt of an Access-Accept, Access-Reject,\n             Access-Challenge, timeout, or retransmission.')
radiusAuthClientExtTimeouts = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1, 14), Counter32()).setUnits('timeouts').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientExtTimeouts.setDescription('The number of authentication timeouts to this server.\n\n             After a timeout, the client may retry to the same\n             server, send to a different server, or\n             give up.  A retry to the same server is counted as a\n             retransmit as well as a timeout.  A send to a different\n             server is counted as a Request as well as a timeout.\n             This counter may experience a discontinuity when the\n             RADIUS Client module within the managed entity is\n             reinitialized, as indicated by the current value of\n             radiusAuthClientCounterDiscontinuity.')
radiusAuthClientExtUnknownTypes = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1, 15), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientExtUnknownTypes.setDescription('The number of RADIUS packets of unknown type that\n             were received from this server on the authentication\n             port.  This counter may experience a discontinuity\n             when the RADIUS Client module within the managed\n             entity is reinitialized, as indicated by the current\n             value of radiusAuthClientCounterDiscontinuity.')
radiusAuthClientExtPacketsDropped = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1, 16), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientExtPacketsDropped.setDescription('The number of RADIUS packets that were\n             received from this server on the authentication port\n             and dropped for some other reason.  This counter may\n             experience a discontinuity when the RADIUS Client\n             module within the managed entity is reinitialized,\n             as indicated by the current value of\n             radiusAuthClientCounterDiscontinuity.')
radiusAuthClientCounterDiscontinuity = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 1, 2, 1, 1, 4, 1, 17), TimeTicks()).setUnits('centiseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAuthClientCounterDiscontinuity.setDescription('The number of centiseconds since the last discontinuity\n             in the RADIUS Client counters.  A discontinuity may\n             be the result of a reinitialization of the RADIUS\n             Client module within the managed entity.')
radiusAuthClientMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 1, 2, 2))
radiusAuthClientMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 1, 2, 2, 1))
radiusAuthClientMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 1, 2, 2, 2))
radiusAuthClientMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 67, 1, 2, 2, 1, 1)).setObjects(*(("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientMIBGroup"),))
if mibBuilder.loadTexts: radiusAuthClientMIBCompliance.setDescription('The compliance statement for authentication clients\n            implementing the RADIUS Authentication Client MIB.\n            Implementation of this module is for IPv4-only\n            entities, or for backwards compatibility use with\n            entities that support both IPv4 and IPv6.')
radiusAuthClientExtMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 67, 1, 2, 2, 1, 2)).setObjects(*(("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientExtMIBGroup"),))
if mibBuilder.loadTexts: radiusAuthClientExtMIBCompliance.setDescription('The compliance statement for authentication\n            clients implementing the RADIUS Authentication\n            Client IPv6 Extensions MIB.  Implementation of\n            this module is for entities that support IPv6,\n            or support IPv4 and IPv6.')
radiusAuthClientMIBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 67, 1, 2, 2, 2, 1)).setObjects(*(("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientIdentifier"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientInvalidServerAddresses"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthServerAddress"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientServerPortNumber"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientRoundTripTime"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientAccessRequests"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientAccessRetransmissions"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientAccessAccepts"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientAccessRejects"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientAccessChallenges"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientMalformedAccessResponses"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientBadAuthenticators"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientPendingRequests"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientTimeouts"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientUnknownTypes"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientPacketsDropped"),))
if mibBuilder.loadTexts: radiusAuthClientMIBGroup.setDescription('The basic collection of objects providing management of\n            RADIUS Authentication Clients.')
radiusAuthClientExtMIBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 67, 1, 2, 2, 2, 2)).setObjects(*(("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientIdentifier"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientInvalidServerAddresses"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthServerInetAddressType"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthServerInetAddress"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientServerInetPortNumber"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientExtRoundTripTime"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientExtAccessRequests"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientExtAccessRetransmissions"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientExtAccessAccepts"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientExtAccessRejects"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientExtAccessChallenges"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientExtMalformedAccessResponses"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientExtBadAuthenticators"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientExtPendingRequests"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientExtTimeouts"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientExtUnknownTypes"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientExtPacketsDropped"), ("RADIUS-AUTH-CLIENT-MIB", "radiusAuthClientCounterDiscontinuity"),))
if mibBuilder.loadTexts: radiusAuthClientExtMIBGroup.setDescription('The collection of extended objects providing\n            management of RADIUS Authentication Clients\n            using version-neutral IP address format.')
mibBuilder.exportSymbols("RADIUS-AUTH-CLIENT-MIB", radiusAuthClientExtMIBCompliance=radiusAuthClientExtMIBCompliance, radiusAuthClientBadAuthenticators=radiusAuthClientBadAuthenticators, radiusAuthClientExtAccessAccepts=radiusAuthClientExtAccessAccepts, radiusAuthClientExtAccessChallenges=radiusAuthClientExtAccessChallenges, radiusAuthClientExtBadAuthenticators=radiusAuthClientExtBadAuthenticators, radiusAuthClientExtAccessRetransmissions=radiusAuthClientExtAccessRetransmissions, radiusAuthClientMIBCompliances=radiusAuthClientMIBCompliances, radiusAuthClientExtPendingRequests=radiusAuthClientExtPendingRequests, radiusAuthServerEntry=radiusAuthServerEntry, radiusAuthClientInvalidServerAddresses=radiusAuthClientInvalidServerAddresses, radiusAuthClientExtAccessRejects=radiusAuthClientExtAccessRejects, radiusAuthClientMIBConformance=radiusAuthClientMIBConformance, radiusAuthServerTable=radiusAuthServerTable, radiusAuthClient=radiusAuthClient, radiusAuthClientAccessRejects=radiusAuthClientAccessRejects, radiusAuthClientAccessRetransmissions=radiusAuthClientAccessRetransmissions, radiusAuthClientExtMalformedAccessResponses=radiusAuthClientExtMalformedAccessResponses, radiusAuthClientIdentifier=radiusAuthClientIdentifier, radiusAuthClientExtPacketsDropped=radiusAuthClientExtPacketsDropped, radiusAuthServerInetAddress=radiusAuthServerInetAddress, radiusAuthServerIndex=radiusAuthServerIndex, radiusAuthClientCounterDiscontinuity=radiusAuthClientCounterDiscontinuity, radiusAuthentication=radiusAuthentication, radiusAuthClientExtRoundTripTime=radiusAuthClientExtRoundTripTime, radiusAuthClientServerPortNumber=radiusAuthClientServerPortNumber, radiusAuthServerExtTable=radiusAuthServerExtTable, radiusAuthClientRoundTripTime=radiusAuthClientRoundTripTime, radiusAuthServerExtEntry=radiusAuthServerExtEntry, radiusAuthClientExtAccessRequests=radiusAuthClientExtAccessRequests, radiusAuthServerExtIndex=radiusAuthServerExtIndex, radiusAuthClientMIBGroups=radiusAuthClientMIBGroups, radiusAuthClientAccessRequests=radiusAuthClientAccessRequests, radiusAuthClientPendingRequests=radiusAuthClientPendingRequests, radiusAuthClientExtUnknownTypes=radiusAuthClientExtUnknownTypes, radiusAuthClientMIB=radiusAuthClientMIB, radiusAuthServerAddress=radiusAuthServerAddress, PYSNMP_MODULE_ID=radiusAuthClientMIB, radiusAuthClientUnknownTypes=radiusAuthClientUnknownTypes, radiusAuthClientAccessAccepts=radiusAuthClientAccessAccepts, radiusAuthClientMalformedAccessResponses=radiusAuthClientMalformedAccessResponses, radiusMIB=radiusMIB, radiusAuthClientServerInetPortNumber=radiusAuthClientServerInetPortNumber, radiusAuthClientPacketsDropped=radiusAuthClientPacketsDropped, radiusAuthClientMIBCompliance=radiusAuthClientMIBCompliance, radiusAuthClientTimeouts=radiusAuthClientTimeouts, radiusAuthClientMIBGroup=radiusAuthClientMIBGroup, radiusAuthClientAccessChallenges=radiusAuthClientAccessChallenges, radiusAuthClientExtTimeouts=radiusAuthClientExtTimeouts, radiusAuthClientExtMIBGroup=radiusAuthClientExtMIBGroup, radiusAuthServerInetAddressType=radiusAuthServerInetAddressType, radiusAuthClientMIBObjects=radiusAuthClientMIBObjects)
